pub struct NativeCapabilityProbeAuthority { /* private fields */ }Implementations
Sourceimpl NativeCapabilityProbeAuthority
impl NativeCapabilityProbeAuthority
pub fn new(config: NativeCapabilityProbeConfig) -> Self
Sourcepub async fn probe(
&mut self,
spec: &AgentSpec,
working_directory: &str,
) -> Result<Vec<CapabilityModelSummary>, CapabilityProbeFailure>
pub async fn probe( &mut self, spec: &AgentSpec, working_directory: &str, ) -> Result<Vec<CapabilityModelSummary>, CapabilityProbeFailure>
Runs at most once for an agent launch contract in this native host. Both success and failure are cached to preserve Orca’s once-per-host fallback semantics.